@@ -1,7 +1,7 @@
 /***** BEGIN LICENSE BLOCK *****
 
 NoScript - a Firefox extension for whitelist driven safe JavaScript execution
-Copyright (C) 2004-2008 Giorgio Maone - g.maone@informaction.com
+Copyright (C) 2004-2009 Giorgio Maone - g.maone@informaction.com
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -117,10 +117,18 @@ var nsopt = {
       var pref = ns.getPref(c);
       Array.forEach(document.getElementById(c + "Opts").getElementsByTagName("checkbox"), function(cbx) {        
         cbx.setAttribute("checked", !(pref & parseInt(cbx.getAttribute("value"))) ? "false" : "true");
-
       });
     });
     
+    if (!ns.clearClickHandler.isSupported(document))
+      ["clearClickOpts", "opt-clearClick.prompt"].forEach(function(id) {
+        document.getElementById(id).setAttribute("hidden", "true"); // Fx <= 1.5
+      });
+    
+    
+    if (!("nsINavHistoryService" in Components.interfaces)) {
+      document.getElementById("opt-placesPrefs").setAttribute("hidden", "true");
+    }
     
     // document.getElementById("policy-tree").view = policyModel;
     window.sizeToContent();
@@ -295,7 +303,7 @@ var nsopt = {
         continue;
       
       item = ul.appendItem(site, site);
-      if(ns.isPermanent(site)) { 
+      if(ns.isMandatory(site)) { 
         item.setAttribute("disabled", "true");
       }
       item.style.fontStyle = (site in tempMap) ? "italic" : "normal";
@@ -324,7 +332,7 @@ var nsopt = {
     
     if(selectedItems.length == 1) {
       var site = selectedItems[0].value;
-      if(!ns.isPermanent(site)) {
+      if(!ns.isMandatory(site)) {
         ul.removeItemAt(ul.getIndexOfItem(selectedItems[0]));
         this.trustedSites.remove(site, true);
       }
@@ -333,7 +341,7 @@ var nsopt = {
     
     var removed = [];
     for(var j = selectedItems.length; j-- > 0;) {
-      if(!ns.isPermanent(site = selectedItems[j].value)) {
+      if(!ns.isMandatory(site = selectedItems[j].value)) {
         removed.push(site);
       }
     }
@@ -356,7 +364,7 @@ var nsopt = {
     this.trustedSites.remove(this.tempSites.sitesList, true, true);
     this.trustedSites.remove(this.gTempSites.sitesList, true, true);
     this.untrustedSites.add(this.gTempSites.sitesList);
-    this.trustedSites.add(ns.permanentSites.sitesList);
+    this.trustedSites.add(ns.mandatorySites.sitesList);
     this.tempSites.sitesString = "";
     this.gTempSites.sitesString = "";
     this.tempRevoked = true;
